/**
  *  \file game/struct-util.cc
  *  \brief Structure Utilities
  *
  *  Utility functions to access raw game structures. These sit
  *  halfway between the "structure" and "class" layers, and are used
  *  to implement class operations.
  *
  *  (c) 2001-2019 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/struct.h"
#include "game/spec.h"
#include "cpluslib/format.h"
#include "io/io.h"

/** Compute ship mass from ship data record.
    \param ship [in] ship data record. Must be completely filled in (i.e.
    not a history record)
    \return mass */
int
getShipMass(const TShip& ship)
{
    int mass = getHull(ship.hull).getMass()
        + ship.ammo
        + ship.ore_cargo[0] + ship.ore_cargo[1]
        + ship.ore_cargo[2] + ship.ore_cargo[3]
        + ship.colonists + ship.supplies;
    if (ship.torp_launcher_count)
        mass += ship.torp_launcher_count * getTorp(ship.torp_type).getMass();
    if (ship.beam_count && ship.beam_type)
        mass += ship.beam_count * getBeam(ship.beam_type).getMass();
    return mass;
}
